@@ -1,7 +1,7 @@
 <?php declare(strict_types = 0);
 /*
 ** Zabbix
-** Copyright (C) 2001-2023 Zabbix SIA
+** Copyright (C) 2001-2024 Zabbix SIA
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
@@ -26,15 +26,18 @@
 
 $this->includeJsFile('administration.userrole.edit.js.php');
 
-$widget = (new CWidget())
+$html_page = (new CHtmlPage())
 	->setTitle(_('User roles'))
-	->setDocUrl(CDocHelper::getUrl(CDocHelper::ADMINISTRATION_USERROLE_EDIT));
+	->setDocUrl(CDocHelper::getUrl(CDocHelper::USERS_USERROLE_EDIT));
+
+$csrf_token = CCsrfTokenHelper::get('userrole');
 
 $form = (new CForm())
 	->addItem((new CVar('form_refresh', $data['form_refresh'] + 1))->removeId())
+	->addItem((new CVar(CCsrfTokenHelper::CSRF_TOKEN_NAME, $csrf_token))->removeId())
 	->setId('userrole-form')
 	->setName('user_role_form')
-	->setAttribute('aria-labelledby', ZBX_STYLE_PAGE_TITLE);
+	->setAttribute('aria-labelledby', CHtmlPage::PAGE_TITLE_ID);
 
 if ($data['roleid'] !== null) {
 	$form->addVar('roleid', $data['roleid']);
@@ -87,28 +90,45 @@ $form_grid->addItem(
 );
 
 foreach ($data['labels']['sections'] as $section_key => $section_label) {
-	$ui = [];
-	foreach ($data['labels']['rules'][$section_key] as $rule_key => $rule_label) {
-		$ui[] = [
-			'id' => $rule_key,
-			'name' => str_replace('.', '_', $rule_key),
-			'label' => $rule_label,
-			'value' => 1,
-			'checked' => array_key_exists($rule_key, $data['rules']['ui']) && $data['rules']['ui'][$rule_key],
-			'unchecked_value' => 0
-		];
+	if (count($data['labels']['rules'][$section_key]) === 1) {
+		$first_rule_key = array_key_first($data['labels']['rules'][$section_key]);
+		$form_grid->addItem([
+			new CLabel($section_label, $first_rule_key),
+			new CFormField(
+				(new CCheckBox(str_replace('.', '_', $first_rule_key), 1))
+					->setId($first_rule_key)
+					->setChecked(
+						array_key_exists($first_rule_key, $data['rules']['ui'])
+						&& $data['rules']['ui'][$first_rule_key]
+					)
+					->setReadonly($data['readonly'])
+					->setUncheckedValue(0)
+			)
+		]);
+	} else {
+		$ui = [];
+		foreach ($data['labels']['rules'][$section_key] as $rule_key => $rule_label) {
+			$ui[] = [
+				'id' => $rule_key,
+				'name' => str_replace('.', '_', $rule_key),
+				'label' => $rule_label,
+				'value' => 1,
+				'checked' => array_key_exists($rule_key, $data['rules']['ui']) && $data['rules']['ui'][$rule_key],
+				'unchecked_value' => 0
+			];
+		}
+		$form_grid->addItem([
+			new CLabel($section_label, $section_key),
+			new CFormField(
+				(new CCheckBoxList())
+					->setWidth(ZBX_TEXTAREA_BIG_WIDTH)
+					->setOptions($ui)
+					->setVertical()
+					->setColumns(3)
+					->setEnabled(!$data['readonly'])
+			)
+		]);
 	}
-	$form_grid->addItem([
-		new CLabel($section_label, $section_key),
-		new CFormField(
-			(new CCheckBoxList())
-				->setWidth(ZBX_TEXTAREA_STANDARD_WIDTH)
-				->setOptions($ui)
-				->setVertical(true)
-				->setColumns(3)
-				->setEnabled(!$data['readonly'])
-		)
-	]);
 }
 
 if (!$data['readonly']) {
@@ -226,28 +246,31 @@ $form_grid->addItem(
 );
 
 $modules = [];
-foreach ($data['labels']['modules'] as $moduleid => $label) {
-	$modules[] = new CDiv(
+
+foreach ($data['labels']['modules'] as $moduleid => $module_name) {
+	$module = new CDiv(
 		(new CCheckBox('modules['.$moduleid.']', 1))
 			->setChecked(
-				array_key_exists($moduleid, $data['rules']['modules']) ? $data['rules']['modules'][$moduleid] : true
+				array_key_exists($moduleid, $data['rules']['modules'])
+					? $data['rules']['modules'][$moduleid]
+					: !array_key_exists($moduleid, $data['disabled_moduleids'])
 			)
 			->setReadonly($data['readonly'])
-			->setLabel($label)
+			->setLabel($module_name)
 			->setUncheckedValue(0)
 	);
+
+	if (array_key_exists($moduleid, $data['disabled_moduleids'])) {
+		$module->addItem((new CSpan([' (', _('Disabled'), ')']))->addClass(ZBX_STYLE_RED));
+	}
+
+	$modules[] = $module;
 }
 
 if ($modules) {
-	$form_grid->addItem([
-		new CFormField(
-			(new CDiv(
-				(new CDiv($modules))
-					->addClass(ZBX_STYLE_COLUMNS)
-					->addClass(ZBX_STYLE_COLUMNS_3)
-			))->setWidth(ZBX_TEXTAREA_STANDARD_WIDTH)
-		)
-	]);
+	$form_grid->addItem(
+		new CFormField($modules)
+	);
 }
 else {
 	$form_grid->addItem(
@@ -364,7 +387,7 @@ if ($data['roleid'] !== null) {
 		(new CRedirectButton(_('Delete'),
 			(new CUrl('zabbix.php'))->setArgument('action', 'userrole.delete')
 				->setArgument('roleids', [$data['roleid']])
-				->setArgumentSID(),
+				->setArgument(CCsrfTokenHelper::CSRF_TOKEN_NAME, $csrf_token),
 			_('Delete selected role?')
 		))
 			->setId('delete')
@@ -387,8 +410,10 @@ $form_grid->addItem(
 $tabs = (new CTabView())->addTab('user_role_tab', _('User role'), $form_grid);
 
 $form->addItem((new CTabView())->addTab('user_role_tab', _('User role'), $form_grid));
-$widget->addItem($form);
-$widget->show();
+
+$html_page
+	->addItem($form)
+	->show();
 
 (new CScriptTag('
 	view.init('.json_encode([
